@@ -10,8 +10,8 @@
 
 #include <KMime/KMimeMessage>
 
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <QDialog>
 
@@ -50,22 +50,21 @@ public Q_SLOTS:
     void accept() override;
 
 private Q_SLOTS:
-    void slotCollectionChanged(int);
-    void slotUpdateButtons();
+    CALENDARSUPPORT_NO_EXPORT void slotCollectionChanged(int);
+    CALENDARSUPPORT_NO_EXPORT void slotUpdateButtons();
 
 Q_SIGNALS:
     void createNote(const Akonadi::Item &note, const Akonadi::Collection &collection);
     void collectionChanged(const Akonadi::Collection &col);
 
 private:
-    void readConfig();
-    void writeConfig();
+    CALENDARSUPPORT_NO_EXPORT void readConfig();
+    CALENDARSUPPORT_NO_EXPORT void writeConfig();
     Akonadi::Collection mCollection;
     Akonadi::Item mItem;
-    QLineEdit *mNoteTitle = nullptr;
+    QLineEdit *const mNoteTitle;
     QPushButton *mOkButton = nullptr;
     KPIMTextEdit::RichTextEditorWidget *mNoteText = nullptr;
     Akonadi::CollectionComboBox *mCollectionCombobox = nullptr;
 };
 }
-
